class Environment(object):
    def __init__(self, name: str, api_url: str, web_url: str, read_only: bool = True):
        self._name = name
        self._api_url = api_url
        self._web_url = web_url
        self._read_only = read_only

    @property
    def name(self) -> str:
        return self._name

    @property
    def api_url(self) -> str:
        return self._api_url

    @property
    def web_url(self) -> str:
        return self._web_url

    @property
    def read_only(self) -> bool:
        return self._read_only

    def __str__(self):
        return self._name

    def __repr__(self):
        return f"{self._name} ({self._api_url})"
