import os
from setuptools import setup

BASE_DIR = os.path.abspath(os.path.dirname(__file__))

REQUIRED = [
    'requests>=2.21.0'
]


def read_files(files):
    data = []
    for file in files:
        with open(file) as f:
            data.append(f.read())
    return "\n".join(data)


meta = {}
with open('./ludialudom/version.py') as f:
    exec(f.read(), meta)

setup(
    name='ludialudom',
    version=meta['__version__'],
    packages=['ludialudom', 'ludialudom.resources'],
    install_requires=REQUIRED,
    url='https://gitlab.backbone.sk/darujme/ludialudom-python',
    license='proprietary',
    author='Jakub Dubec',
    author_email='jakub.dubec@backbone.sk',
    description='Python API client for LudiaLudom',
    long_description=read_files(['README.md', 'CHANGELOG.md']),
    long_description_content_type='text/markdown',
    keywords=['ludialudom', 'requests', 'client', 'api'],
    classifiers=[
        # As from https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Intended Audience :: Developers',
        'License :: Other/Proprietary License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
